==> vlc-debug-1:3.0.22-3-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-a89e30a4d2cb156b8a4f68aa52b11ebd0d8eb25a/modules/gui/qt/playercontrols_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xdd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xc4,0x5,0x9d,0xe,0x0,0x46,0x93,0x3a,0x1f,0x30,0xaf,0x73,
  0x1b,0x42,0x49,0x41,0x2b,0xbb,0xbf,0xf9,0x4f,0x68,0x79,0xc0,0xe,0x2b,0xec,0x55,
  0xa1,0xeb,0xdf,0x8c,0x78,0x97,0x12,0x38,0x68,0x40,0x39,0x1,0x34,0x0,0x32,0x0,
  0x2f,0x0,0xd,0xc0,0x9,0x34,0x7d,0xaa,0x39,0xc9,0xa1,0x83,0xc4,0x75,0x8d,0xbd,
  0x9d,0x7f,0x54,0x94,0x3b,0x30,0xcf,0x13,0x25,0x22,0xcf,0x83,0xd7,0xd3,0xd7,0x23,
  0x68,0xf8,0x94,0xb3,0x64,0xe6,0x5b,0xee,0xb8,0x11,0xff,0xa2,0xaf,0xe1,0x44,0x89,
  0x48,0xf3,0x87,0xb5,0x85,0x1,0xae,0x45,0x95,0x96,0x2,0x16,0xaf,0x68,0x19,0x61,
  0x62,0xeb,0xb2,0x73,0xa3,0x2d,0x5f,0xf0,0x5b,0x6a,0x15,0xb1,0x42,0x6b,0xd7,0x9a,
  0x14,0x8a,0xdb,0x8d,0x41,0xd0,0xb6,0x6b,0x7d,0xf4,0x74,0x39,0x97,0x12,0x11,0x16,
  0x6f,0xa5,0x79,0xc0,0x3c,0x78,0x39,0x1,0x53,0xbb,0x8a,0xc4,0x6f,0xbf,0x94,0xac,
  0x49,0x27,0xf1,0x92,0x61,0x59,0x28,0xae,0x6b,0xa5,0x5c,0xa6,0xb,0xb9,0x4b,0x45,
  0x4d,0xc4,0x9f,0xa7,0xf9,0x1e,0x76,0xa8,0xcc,0xef,0xa9,0x86,0xee,0x4b,0xed,0x2d,
  0xbe,0xf9,0x93,0x4a,0x89,0x8a,0x1,0xcc,0x83,0x97,0xf3,0xde,0x21,0xf6,0x36,0xc2,
  0xfb,0x36,0xea,0xbf,0x43,0xba,0xb7,0x9a,0x52,0x23,0xbf,0xb2,0x4f,0x2b,0xbc,0x6,
  0xe9,0x2c,0xe9,0x93,0x9f,0x35,0xde,0x89,0xcf,0x70,0x5b,0xd4,0x47,0x3b,0xcc,0x1,
  0x95,0xa9,0xed,0xe9,0x5e,0x15,0x80,0x84,0xa8,0xa1,0x8a,0x48,0xd1,0x48,0x93,0x82,
  0x42,0x36,0xc6,0x40,0x44,0x94,0x9e,0xa4,0xd,0x21,0x14,0x85,0x28,0x23,0x30,0x32,
  0x93,0xb1,0x4d,0xa,0x8d,0x1,0xb0,0xc2,0xc9,0xb7,0x4f,0x46,0x23,0x31,0x29,0x9f,
  0x9c,0x12,0x8c,0xbb,0x19,0x27,0x7e,0x91,0x9d,0x23,0x81,0x29,0x8a,0xb5,0x4,0x51,
  0x82,0xd5,0x52,0x2a,0x17,0x47,0x3c,0x87,0xa0,0x12,0xcd,0xe,0x8f,0x16,0x91,0x1e,
  0xd5,0x3c,0x9c,0x8f,0x51,0x5a,0x4d,0x67,0x7d,0x6a,0x89,0xe,0xa2,0xae,0xc6,0x8b,
  0x0,0x5,0xb5,0xe9,0xc5,0xd4,0x4e,0x58,0x61,0xb3,0x98,0xd4,0x1a,0x9,0x60,0x49,
  0x91,0x8f,0xa0,0x52,0xd1,0x58,0x1,0x14,0xac,0xd,0xc9,0x69,0xa0,0x56,0x91,0x45,
  0x51,0xa4,0x10,0x32,0xeb,0xf9,0x59,0x9b,0xa,0xf9,0x76,0x49,0xca,0x1c,0x8e,0x87,
  0x90,0x40,0x71,0x68,0xde,0x18,0xe0,0x83,0x9c,0xd3,0xea,0xaa,0x18,0xa3,0x88,0x51,
  0x11,0x8b,0x63,0xc0,0x86,0x87,0x14,0x5e,0xa2,0xc3,0x58,0x9f,0x6d,0x8a,0x98,0xa8,
  0x8e,0xf4,0x50,0x91,0xb,0x80,0x94,0xfa,0xcc,0xb,0x5c,0x69,0xc8,0x87,0x18,0xe0,
  0x95,0xe8,0xfe,0x97,0xa1,0xb3,0x14,0xc1,0xf7,0x1b,0x34,0xe2,0x59,0xf6,0x28,0xf9,
  0x58,0xa4,0xc,0xa3,0xa6,0x2c,0xb3,0xb3,0x5a,0xf8,0x8a,0x85,0x88,0xf7,0xc4,0x14,
  0xf7,0x32,0x21,0xb3,0xc4,0x7f,0xa0,0xaa,0x36,0x10,0xac,0x2,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // PlayerControls
  0x0,0xe,
  0x3,0x44,0xf,0x33,
  0x0,0x50,
  0x0,0x6c,0x0,0x61,0x0,0x79,0x0,0x65,0x0,0x72,0x0,0x43,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml/VLC/PlayerControls
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml/VLC/PlayerControls/qmldir
  0x0,0x0,0x0,0x44,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_playercontrols_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_playercontrols_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_playercontrols_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_playercontrols_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_playercontrols_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_playercontrols_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> vlc-debug-1:3.0.22-4-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-a89e30a4d2cb156b8a4f68aa52b11ebd0d8eb25a/modules/gui/qt/playercontrols_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xdd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xc4,0x5,0x9d,0xe,0x0,0x46,0x93,0x3a,0x1f,0x30,0xaf,0x73,
  0x1b,0x42,0x49,0x41,0x2b,0xbb,0xbf,0xf9,0x4f,0x68,0x79,0xc0,0xe,0x2b,0xec,0x55,
  0xa1,0xeb,0xdf,0x8c,0x78,0x97,0x12,0x38,0x68,0x40,0x39,0x1,0x34,0x0,0x32,0x0,
  0x2f,0x0,0xd,0xc0,0x9,0x34,0x7d,0xaa,0x39,0xc9,0xa1,0x83,0xc4,0x75,0x8d,0xbd,
  0x9d,0x7f,0x54,0x94,0x3b,0x30,0xcf,0x13,0x25,0x22,0xcf,0x83,0xd7,0xd3,0xd7,0x23,
  0x68,0xf8,0x94,0xb3,0x64,0xe6,0x5b,0xee,0xb8,0x11,0xff,0xa2,0xaf,0xe1,0x44,0x89,
  0x48,0xf3,0x87,0xb5,0x85,0x1,0xae,0x45,0x95,0x96,0x2,0x16,0xaf,0x68,0x19,0x61,
  0x62,0xeb,0xb2,0x73,0xa3,0x2d,0x5f,0xf0,0x5b,0x6a,0x15,0xb1,0x42,0x6b,0xd7,0x9a,
  0x14,0x8a,0xdb,0x8d,0x41,0xd0,0xb6,0x6b,0x7d,0xf4,0x74,0x39,0x97,0x12,0x11,0x16,
  0x6f,0xa5,0x79,0xc0,0x3c,0x78,0x39,0x1,0x53,0xbb,0x8a,0xc4,0x6f,0xbf,0x94,0xac,
  0x49,0x27,0xf1,0x92,0x61,0x59,0x28,0xae,0x6b,0xa5,0x5c,0xa6,0xb,0xb9,0x4b,0x45,
  0x4d,0xc4,0x9f,0xa7,0xf9,0x1e,0x76,0xa8,0xcc,0xef,0xa9,0x86,0xee,0x4b,0xed,0x2d,
  0xbe,0xf9,0x93,0x4a,0x89,0x8a,0x1,0xcc,0x83,0x97,0xf3,0xde,0x21,0xf6,0x36,0xc2,
  0xfb,0x36,0xea,0xbf,0x43,0xba,0xb7,0x9a,0x52,0x23,0xbf,0xb2,0x4f,0x2b,0xbc,0x6,
  0xe9,0x2c,0xe9,0x93,0x9f,0x35,0xde,0x89,0xcf,0x70,0x5b,0xd4,0x47,0x3b,0xcc,0x1,
  0x95,0xa9,0xed,0xe9,0x5e,0x15,0x80,0x84,0xa8,0xa1,0x8a,0x48,0xd1,0x48,0x93,0x82,
  0x42,0x36,0xc6,0x40,0x44,0x94,0x9e,0xa4,0xd,0x21,0x14,0x85,0x28,0x23,0x30,0x32,
  0x93,0xb1,0x4d,0xa,0x8d,0x1,0xb0,0xc2,0xc9,0xb7,0x4f,0x46,0x23,0x31,0x29,0x9f,
  0x9c,0x12,0x8c,0xbb,0x19,0x27,0x7e,0x91,0x9d,0x23,0x81,0x29,0x8a,0xb5,0x4,0x51,
  0x82,0xd5,0x52,0x2a,0x17,0x47,0x3c,0x87,0xa0,0x12,0xcd,0xe,0x8f,0x16,0x91,0x1e,
  0xd5,0x3c,0x9c,0x8f,0x51,0x5a,0x4d,0x67,0x7d,0x6a,0x89,0xe,0xa2,0xae,0xc6,0x8b,
  0x0,0x5,0xb5,0xe9,0xc5,0xd4,0x4e,0x58,0x61,0xb3,0x98,0xd4,0x1a,0x9,0x60,0x49,
  0x91,0x8f,0xa0,0x52,0xd1,0x58,0x1,0x14,0xac,0xd,0xc9,0x69,0xa0,0x56,0x91,0x45,
  0x51,0xa4,0x10,0x32,0xeb,0xf9,0x59,0x9b,0xa,0xf9,0x76,0x49,0xca,0x1c,0x8e,0x87,
  0x90,0x40,0x71,0x68,0xde,0x18,0xe0,0x83,0x9c,0xd3,0xea,0xaa,0x18,0xa3,0x88,0x51,
  0x11,0x8b,0x63,0xc0,0x86,0x87,0x14,0x5e,0xa2,0xc3,0x58,0x9f,0x6d,0x8a,0x98,0xa8,
  0x8e,0xf4,0x50,0x91,0xb,0x80,0x94,0xfa,0xcc,0xb,0x5c,0x69,0xc8,0x87,0x18,0xe0,
  0x95,0xe8,0xfe,0x97,0xa1,0xb3,0x14,0xc1,0xf7,0x1b,0x34,0xe2,0x59,0xf6,0x28,0xf9,
  0x58,0xa4,0xc,0xa3,0xa6,0x2c,0xb3,0xb3,0x5a,0xf8,0x8a,0x85,0x88,0xf7,0xc4,0x14,
  0xf7,0x32,0x21,0xb3,0xc4,0x7f,0xa0,0xaa,0x36,0x10,0xac,0x2,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // PlayerControls
  0x0,0xe,
  0x3,0x44,0xf,0x33,
  0x0,0x50,
  0x0,0x6c,0x0,0x61,0x0,0x79,0x0,0x65,0x0,0x72,0x0,0x43,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml/VLC/PlayerControls
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml/VLC/PlayerControls/qmldir
  0x0,0x0,0x0,0x44,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_playercontrols_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_playercontrols_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_playercontrols_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_playercontrols_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_playercontrols_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_playercontrols_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
